======
AI-API
======

AI API

Note:

    This project is in beta stage, the API may change.

Contents:

.. toctree::
   :maxdepth: 2

   intro
   API <api>
   developer

* Web site: http://www.jdhp.org/software_en.html#aiapi
* Online documentation: https://jdhp-dev.gitlab.io/aiapi
* Source code: https://gitlab.com/jdhp-dev/ai-api
* Issue tracker: https://gitlab.com/jdhp-dev/ai-api/issues
* aiapi on PyPI: https://pypi.org/project/aiapi

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

Credits
=======

.. include:: ../AUTHORS
   :literal:

License
=======

.. highlight:: none

.. include:: ../LICENSE
   :literal:

